@@ -43,6 +43,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "gdm-common.h"
 #include "gdm-greeter-server.h"
 
 #define GDM_GREETER_SERVER_DBUS_PATH      "/org/gnome/DisplayManager/GreeterServer"
@@ -238,6 +239,13 @@ gdm_greeter_server_problem (GdmGreeterServer *greeter_server,
         return TRUE;
 }
 
+gboolean
+gdm_greeter_server_authentication_failed (GdmGreeterServer *greeter_server)
+{
+        send_dbus_void_signal (greeter_server, "AuthenticationFailed");
+        return TRUE;
+}
+
 gboolean
 gdm_greeter_server_reset (GdmGreeterServer *greeter_server)
 {
@@ -752,7 +760,6 @@ do_introspect (DBusConnection *connection,
                                "      <arg name=\"layout_name\" type=\"s\"/>\n"
                                "    </signal>\n"
                                "    <signal name=\"DefaultSessionNameChanged\">\n"
-                               "    <signal name=\"DefaultSessionNameChanged\">\n"
                                "      <arg name=\"session_name\" type=\"s\"/>\n"
                                "    </signal>\n"
                                "    <signal name=\"TimedLoginRequested\">\n"
@@ -763,6 +770,8 @@ do_introspect (DBusConnection *connection,
                                "    </signal>\n"
                                "    <signal name=\"Reset\">\n"
                                "    </signal>\n"
+                               "    <signal name=\"AuthenticationFailed\">\n"
+                               "    </signal>\n"
                                "    <signal name=\"UserAuthorized\">\n"
                                "    </signal>\n"
                                "  </interface>\n");
@@ -886,7 +895,7 @@ allow_user_function (DBusConnection *connection,
                 return FALSE;
         }
 
-        pwent = getpwnam (greeter_server->priv->user_name);
+        gdm_get_pwent_for_name (greeter_server->priv->user_name, &pwent);
         if (pwent == NULL) {
                 return FALSE;
         }
