@@ -57,16 +57,18 @@ typedef struct
 
 GType                  gdm_greeter_panel_get_type                       (void);
 
-GtkWidget            * gdm_greeter_panel_new                            (void);
+GtkWidget            * gdm_greeter_panel_new                            (GdkScreen *screen,
+                                                                         int        monitor,
+                                                                         gboolean   is_local);
 
 void                   gdm_greeter_panel_show_user_options              (GdmGreeterPanel *panel);
 void                   gdm_greeter_panel_hide_user_options              (GdmGreeterPanel *panel);
 void                   gdm_greeter_panel_reset                          (GdmGreeterPanel *panel);
+void                   gdm_greeter_panel_set_keyboard_layout            (GdmGreeterPanel *panel,
+                                                                         const char      *layout_name);
 
 void                   gdm_greeter_panel_set_default_language_name      (GdmGreeterPanel *panel,
                                                                          const char      *language_name);
-void                   gdm_greeter_panel_set_default_layout_name        (GdmGreeterPanel *panel,
-                                                                         const char      *layout_name);
 void                   gdm_greeter_panel_set_default_session_name       (GdmGreeterPanel *panel,
                                                                          const char      *session_name);
 G_END_DECLS
