@@ -108,7 +108,7 @@ get_font_height_for_widget (GtkWidget *widget)
         gtk_widget_ensure_style (widget);
         context = gtk_widget_get_pango_context (widget);
         metrics = pango_context_get_metrics (context,
-                                             widget->style->font_desc,
+                                             gtk_widget_get_style (widget)->font_desc,
                                              pango_context_get_language (context));
 
         ascent = pango_font_metrics_get_ascent (metrics);
@@ -150,13 +150,8 @@ update_other_user_visibility (GdmUserChooserWidget *widget)
                 goto out;
         }
 
-        number_of_users = gdm_chooser_widget_get_number_of_items (GDM_CHOOSER_WIDGET (widget));
-
-        /* we hide the Other user if it's the last one, and we show it
-         * if there's another user */
-        if (number_of_users == 1 && widget->priv->has_user_other) {
-                remove_user_other (widget);
-        } if (number_of_users >= 1 && !widget->priv->has_user_other) {
+        /* Always show the Other user if requested */
+        if (!widget->priv->has_user_other) {
                 add_user_other (widget);
         }
 
@@ -185,6 +180,9 @@ update_item_for_user (GdmUserChooserWidget *widget,
         char         *escaped_username;
         char         *escaped_real_name;
 
+        if (!gdm_user_is_loaded (user)) {
+                return;
+        }
 
         size = get_icon_height_for_widget (GTK_WIDGET (widget));
         pixbuf = gdm_user_render_icon (user, size);
@@ -235,6 +233,14 @@ on_item_load (GdmChooserWidget     *widget,
                 return;
         }
 
+        if (strcmp (id, GDM_USER_CHOOSER_USER_OTHER) == 0) {
+                return;
+        }
+
+        if (strcmp (id, GDM_USER_CHOOSER_USER_GUEST) == 0) {
+                return;
+        }
+
         user = gdm_user_manager_get_user (user_chooser->priv->manager, id);
         if (user != NULL) {
                 update_item_for_user (user_chooser, user);
@@ -253,7 +259,7 @@ add_user_other (GdmUserChooserWidget *widget)
                                       * manually instead of choosing from
                                       * a list.
                                       */
-                                     C_("user", "Other..."),
+                                     C_("user", "Other…"),
                                      _("Choose a different account"),
                                      0,
                                      FALSE,
@@ -269,7 +275,7 @@ add_user_guest (GdmUserChooserWidget *widget)
                                      GDM_USER_CHOOSER_USER_GUEST,
                                      widget->priv->stock_person_pixbuf,
                                      _("Guest"),
-                                     _("Login as a temporary guest"),
+                                     _("Log in as a temporary guest"),
                                      0,
                                      FALSE,
                                      TRUE,
@@ -285,7 +291,7 @@ add_user_auto (GdmUserChooserWidget *widget)
                                      GDM_USER_CHOOSER_USER_AUTO,
                                      NULL,
                                      _("Automatic Login"),
-                                     _("Automatically login to the system after selecting options"),
+                                     _("Automatically log into the system after selecting options"),
                                      0,
                                      FALSE,
                                      TRUE,
